#!/bin/bash
#Mithat Konar - 2009/05/28

# Requires gksudo, zenity, synaptic

# ===========
# UI strings
# ===========
ui_checkUpdatesTitle="Check for updates?"
ui_check4updates="Check for software updates?"
ui_checkUpdatesPrompt1="It has been a while since you last checked for software updates."
ui_checkUpdatesPrompt2="Shall I check for updates?"
ui_noUpdatesPrompt="I can't tell when you last checked for software updates."
ui_warnSingleProcessTitle="checkupdates already running"
ui_warnSingleProcess="checkupdates is already running.\n\nOnly one instance per user is permitted."
ui_zenityNotFound="zenity not found. Install zenity to use this script."
ui_gksudoNotFound="gksudo not found. Install gksudo to use this script."

# ================
# global constants
# ================
APPDIR=`dirname "$0"`
cd -P "$APPDIR"
APPDIR="`pwd`"
#lastupdate="$APPDIR/lastupdated"	# file used to keep track of last update
lastupdate="$HOME/.config/skinny/exc/lastupdated"	# file used to keep track of last update
iconPath="$APPDIR/icon.png"			# path to icon used in messages, etc

oneHour=3600		# seconds in an hour
oneDay=86400		# seconds in a day
oneWeek=604800		# seconds in a week
twoWeeks=1209600	# seconds in two weeks
updatePeriod=$oneWeek

# ===========
# "main"
# ===========

# check for zenity and gksudo
isZenity=`which zenity`
if [ -z $isZenity ] ; then
	echo "${0}: $ui_zenityNotFound"
	exit 1
fi
isGksudo=`which gksudo`
if [ -z $isGksudo ] ; then
	echo "${0}: $ui_gksudoNotFound"
	exit 1
fi

# Check to see if the process is already running.
pid=$$
thisUser=`whoami`
tmpProcInfo=`ps -o pid,command -U $thisUser -u $thisUser`
procInfo=`echo -e "$tmpProcInfo" | grep check-updates.sh | grep /bin/bash | grep -v $pid`

if [ -n "$procInfo" ] ; then	# if the process is running
	zenity --warning --title="$ui_warnSingleProcessTitle" --text="$ui_warnSingleProcess"
	#echo -e "${ui_warnSingleProcessTitle}:\n${ui_warnSingleProcess}\n$procInfo"
	exit 1
fi

# go
while [ 0 -eq 0 ] ; do
	doUpdate=1			# assume we will NOT do an update (1 means FALSE in bash)
	isTouch=1			# assume we will NOT touch lastupdate file
	if [ -e "$lastupdate" ] ; then				# if lastupdate file exists
		updateEpoch=`stat --format=%Y "$lastupdate"`	# check if it's timestamp is over a week (or whatever) old
		nowEpoch=`date +%s`
		lapsed=$((nowEpoch-updateEpoch))
		if [ $lapsed -ge $updatePeriod ] ; then
			##notify-send --icon="$iconPath" "$ui_checkUpdatesTitle" "${ui_checkUpdatesPrompt1}..."
			zenity --notification --window-icon="$iconPath" --text="$ui_check4updates"
			zenity --question --window-icon="$iconPath" --title="$ui_checkUpdatesTitle" --text="${ui_checkUpdatesPrompt1}\n\n${ui_checkUpdatesPrompt2}"
			doUpdate=$?
			isTouch=0		# touch lastupdate file
		fi
	else
		##notify-send --icon="$iconPath" "$ui_checkUpdatesTitle" "${ui_noUpdatesPrompt}..."
		zenity --notification --window-icon="$iconPath" --text="$ui_check4updates"
		zenity --question --window-icon="$iconPath" --title="$ui_checkUpdatesTitle" --text="${ui_noUpdatesPrompt}\n\n$ui_checkUpdatesPrompt2"
		doUpdate=$?
		isTouch=0		# touch lastupdate file
	fi

	if [ $doUpdate = "0" ] ; then
		me=`whoami`
		if [ $me = "root" ] ; then
			"$APPDIR/update.sh"
			update-menus
		else
			gksudo -D "Software Updates" "$APPDIR/update.sh"
			update-menus
		fi
	fi
	if [ $isTouch -eq 0 ] ; then 
		touch "$lastupdate"
	fi
#	sleep 60		# sleep for a while
	sleep $oneHour		# sleep for a while
done
